@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-12-08'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -322,11 +322,7 @@ sub _process_script {
                             last SHOW_RESULT;
                         }
                         $res = $pa->request(call => $url, \%extra);
-                        my $naked = $meta->{result_naked};
                         my $format = $res->[3]{'cmdline.default_format'} // $cli->{default_format} // 'text-pretty';
-                        if ($naked) {
-                            $res = [200, "OK (envelope added automatically)", $res];
-                        }
                         require Perinci::Result::Format::Lite;
                         my $fres = Perinci::Result::Format::Lite::format($res, $format);
                         $fres =~ s/^/ /gm;
@@ -670,7 +666,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.49 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-12-08.
+This document describes version 0.50 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
